@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2016-2022 Matthias Klumpp <matthias@tenstral.net>
+ * Copyright (C) 2016-2024 Matthias Klumpp <matthias@tenstral.net>
  *
  * Licensed under the GNU Lesser General Public License Version 2.1
  *
@@ -18,7 +18,7 @@
  * along with this library.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#if !defined (__APPSTREAM_H) && !defined (AS_COMPILATION)
+#if !defined(__APPSTREAM_H) && !defined(AS_COMPILATION)
 #error "Only <appstream.h> can be included directly."
 #endif
 
@@ -26,19 +26,21 @@
 #define __AS_STEMMER_H
 
 #include <glib-object.h>
+#include "as-macros-private.h"
 
-G_BEGIN_DECLS
+AS_BEGIN_PRIVATE_DECLS
 
-#define AS_TYPE_STEMMER	(as_stemmer_get_type ())
+#define AS_TYPE_STEMMER (as_stemmer_get_type ())
 G_DECLARE_FINAL_TYPE (AsStemmer, as_stemmer, AS, STEMMER, GObject)
 
-AsStemmer		*as_stemmer_get (const gchar *locale);
+AS_INTERNAL_VISIBLE
+AsStemmer *as_stemmer_get (const gchar *locale);
 
-void			as_stemmer_reload (AsStemmer *stemmer,
-						const gchar *lang);
-gchar			*as_stemmer_stem (AsStemmer *stemmer,
-						const gchar *term);
+void	   as_stemmer_reload (AsStemmer *stemmer, const gchar *locale);
 
-G_END_DECLS
+AS_INTERNAL_VISIBLE
+gchar *as_stemmer_stem (AsStemmer *stemmer, const gchar *term);
+
+AS_END_PRIVATE_DECLS
 
 #endif /* __AS_STEMMER_H */
