@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2012-2022 Matthias Klumpp <matthias@tenstral.net>
+ * Copyright (C) 2012-2024 Matthias Klumpp <matthias@tenstral.net>
  *
  * Licensed under the GNU Lesser General Public License Version 2.1
  *
@@ -97,8 +97,7 @@ as_component_sort_values (AsComponent *cpt)
 	for (i = 0; i < provideds->len; i++) {
 		AsProvided *prov = AS_PROVIDED (g_ptr_array_index (provideds, i));
 
-		g_ptr_array_sort (as_provided_get_items (prov),
-				  as_sort_strings_cb);
+		g_ptr_array_sort (as_provided_get_items (prov), as_sort_strings_cb);
 	}
 }
 
@@ -113,8 +112,7 @@ as_sort_components_cb (gconstpointer a, gconstpointer b)
 	AsComponent *cpt1 = *((AsComponent **) a);
 	AsComponent *cpt2 = *((AsComponent **) b);
 
-	return g_strcmp0 (as_component_get_id (cpt1),
-			  as_component_get_id (cpt2));
+	return g_strcmp0 (as_component_get_id (cpt1), as_component_get_id (cpt2));
 }
 
 /**
@@ -129,8 +127,30 @@ as_sort_components (GPtrArray *cpts)
 /**
  * as_gbytes_from_literal:
  */
-GBytes*
+GBytes *
 as_gbytes_from_literal (const gchar *string)
 {
 	return g_bytes_new_static (string, strlen (string));
 }
+
+/**
+ * as_ptr_array_strjoin:
+ */
+gchar *
+as_ptr_array_strjoin (GPtrArray *array, const gchar *sep)
+{
+	gsize sep_len;
+	GString *str = g_string_new ("");
+
+	sep_len = strlen (sep);
+	for (guint i = 0; i < array->len; ++i) {
+		g_string_append_printf (str,
+					"%s%s",
+					(const gchar *) g_ptr_array_index (array, i),
+					sep);
+	}
+	if (str->len > sep_len)
+		g_string_truncate (str, str->len - sep_len);
+
+	return g_string_free (str, FALSE);
+}
